package eu.beesoft.abeona.example;

import java.io.IOException;
import java.util.Properties;
import eu.beesoft.abeona.Abeona;
import eu.beesoft.abeona.LicenseException;
import eu.beesoft.abeona.LicenseGenerator;
import eu.beesoft.abeona.Product;
import eu.beesoft.abeona.Database;

/**
 * This example demonstrates how to create a new license file out of GUI tool -
 * just from code.
 * 
 * @author Eugen Kocak
 */
public class BuildLicenseFromCode {

	public BuildLicenseFromCode (Abeona abeona) {

		// prepare your properties for generated license
		Properties properties = new Properties ();
		properties.setProperty ("customer", "Very Big Company");
		properties.setProperty ("dbAccess", "enabled");
		properties.setProperty ("netUpdate", "disabled");
		properties.setProperty ("user.count", "25");

		// get product database
		// it contains all your product (application) records
		Database db = abeona.getDatabase ();

		// get product by ID
		// here we obtain product #10
		// you can see right product ID via GUI tool
		Product product = db.getProduct (10);

		// get license generator
		LicenseGenerator generator = abeona.getLicenseGenerator ();

		// sign and store license
		try {
			Properties signedProperties = generator.generate (properties,
			        product);
			generator.storeLicense (signedProperties, product,
			        "c:/myNew.license");
		}
		catch (LicenseException le) {
			// TODO
			// thrown when cannot sign properties
		}
		catch (IOException ioe) {
			// TODO
			// thrown when cannot write properties to file
		}
	}



	public static void main (String[] arguments) {
		// you must always call main() method in Abeona
		// it requires as argument name of class to run
		// if it is null, GUI tool is invoked
		Abeona.main (new String[] { BuildLicenseFromCode.class.getName () });

		// or you can run Abeona from command line this way:
		// java  eu.beesoft.abeona.Abeona  eu.beesoft.abeona.example.BuildLicenseFromCode
	}
}
